@@ -86,6 +86,18 @@ func IsSlice(v any) bool {
 
 var zeroType = reflect.TypeOf((*types.Zeroer)(nil)).Elem()
 
+var isZeroCache sync.Map
+
+func implementsIsZero(tp reflect.Type) bool {
+	v, ok := isZeroCache.Load(tp)
+	if ok {
+		return v.(bool)
+	}
+	implements := tp.Implements(zeroType)
+	isZeroCache.Store(tp, implements)
+	return implements
+}
+
 // IsTruthfulValue returns whether the given value has a meaningful truth value.
 // This is based on template.IsTrue in Go's stdlib, but also considers
 // IsZero and any interface value will be unwrapped before it's considered
@@ -101,7 +113,11 @@ func IsTruthfulValue(val reflect.Value) (truth bool) {
 		return
 	}
 
-	if val.Type().Implements(zeroType) {
+	if val.Kind() == reflect.Pointer && val.IsNil() {
+		return
+	}
+
+	if implementsIsZero(val.Type()) {
 		return !val.Interface().(types.Zeroer).IsZero()
 	}
 
@@ -134,12 +150,7 @@ type methodKey struct {
 	name string
 }
 
-type methods struct {
-	sync.RWMutex
-	cache map[methodKey]int
-}
-
-var methodCache = &methods{cache: make(map[methodKey]int)}
+var methodCache sync.Map
 
 // GetMethodByName is the same as reflect.Value.MethodByName, but it caches the
 // type lookup.
@@ -157,22 +168,16 @@ func GetMethodByName(v reflect.Value, name string) reflect.Value {
 // -1 if no such method exists.
 func GetMethodIndexByName(tp reflect.Type, name string) int {
 	k := methodKey{tp, name}
-	methodCache.RLock()
-	index, found := methodCache.cache[k]
-	methodCache.RUnlock()
+	v, found := methodCache.Load(k)
 	if found {
-		return index
+		return v.(int)
 	}
-
-	methodCache.Lock()
-	defer methodCache.Unlock()
-
 	m, ok := tp.MethodByName(name)
-	index = m.Index
+	index := m.Index
 	if !ok {
 		index = -1
 	}
-	methodCache.cache[k] = index
+	methodCache.Store(k, index)
 
 	if !ok {
 		return -1
@@ -245,7 +250,7 @@ func ToSliceAny(v any) ([]any, bool) {
 		vvv := reflect.ValueOf(v)
 		if vvv.Kind() == reflect.Slice {
 			out := make([]any, vvv.Len())
-			for i := 0; i < vvv.Len(); i++ {
+			for i := range vvv.Len() {
 				out[i] = vvv.Index(i).Interface()
 			}
 			return out, true
